/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core;

import java.io.Serializable;
import java.util.Vector;

/**
 * This class represents the properties of select parameter groups.
 * A select parameter group has several possible values, of which exactly one
 * is selected.
 * 
 */

public class SelectParameterGroup extends ParameterGroup implements Serializable  {	
	private static final long serialVersionUID = 1L;

	/** 
	 * Possible choices of this parameter as specified in the configuration 
	 * xml-file.
	 */	
	private Vector<String> choices;
	
	/** 
	 * Default choices of this parameter as specified in the configuration 
	 * xml-file.
	 */	
	private String defaultChoice;

	/** 
	 * Current choice value of this parameter.
	 */	
	private String choiceValue;
	
	/**
	 * Creates the parameter group according to the passed values. 
	 * The first element of the choices vector is set as the default choice.
	 */
	public SelectParameterGroup(String name, String key, String description, String successor, boolean visible, boolean enabled, Vector<String> choices) {
		super(name, key, description, successor, visible, enabled);
		this.choices = choices;
		this.defaultChoice = choices.firstElement();
		this.choiceValue = defaultChoice;
	}
	
	public String getDefaultChoice() {
		return defaultChoice;
	}
	
	public String getChoiceValue(){
		return this.choiceValue;
	}
	
	public void setChoiceValue(String choice){		
		this.choiceValue = choice;
	}

	public Vector<String> getChoices(){
		return choices ;
	}
	
	public void setDefaultValue(String defaultValue) {
		this.defaultChoice = defaultValue;
	}
	
	@Override
	public String getDescription() {
		return description;
	}
	
	@Override
	public String getDisplayFriendlyValueString() {
		return choiceValue;
	}

	@Override
	public String getCommandlineCallString() {
		if (enabled)
			return key + getDisplayFriendlyValueString();					
		else
			return "";
	}	

	/**
	 * Returns a string showing the format used for entering and displaying 
	 * this parameter.
	 */
	public String getFormat() {
		return "<" + name + ">";
	}
}
