/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core;


import java.io.Serializable;

import core.graph.JobNode;
import core.history.ChangeStaticTextParameterValueHistoryObject;

/**
 * This class represents static text parameters. They consist of one
 * value. 
 */


public class StaticTextParameter extends TextParameter implements Serializable {
	private static final long serialVersionUID = 1L;
	
	/**
	 * Temporary value of this parameter. Used to allow safe parsing of
	 * potentially malformated user input without interfering with the
	 * current value.
	 */
	private String temporaryValue;
	
	/**
	 * Current value of this parameter. 
	 */
	private String value;

	
	/**
	 * Creates the parameter group according to the passed values. 
	 */
	public StaticTextParameter(String name, String description, String successor) {
		super(name, description, successor);
		temporaryValue = "";
		value = "";
	}

	@Override
	public String getFormat() {
		return "<" + name + ">";
	}
	
	@Override
	public String parseInputToTemporaryValue(String text) {
		int spacePos = text.indexOf(" ");
		String curValue = text;
		String result = "";
		if (spacePos != -1) {
			curValue = text.substring(0, spacePos);
			result = text.substring(spacePos + 1, text.length());
		}
		temporaryValue = curValue;
		return result;
	}

	@Override
	public String getTemporaryValue() {
		return temporaryValue;
	}

	@Override
	public String getValue() {
		return value;
	}

	@Override
	public ChangeStaticTextParameterValueHistoryObject createHistoryObjectToInheritTemporaryValues() {
		if (temporaryValue.equals(value))
			return null;
		else
			return new ChangeStaticTextParameterValueHistoryObject(this, temporaryValue);
	}

	public void setValue(String newValue) {
		this.value = newValue;
	}
	
}
