/*
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package core;

import java.io.File;
import java.util.Hashtable;
import java.util.Vector;

/**
 * This class extends the standard File class with an
 * additional list of types, which represent more in 
 * detail which kind of informations are stored in the
 * file associated with an object of this class.
 */
public class TypedFile extends File {
	private static final long serialVersionUID = 1L;
	private static String osName = System.getProperty("os.name");

	/**
	 * Stores a vector containing all types contained
	 * by this file.
	 */
	private Vector<String> types;
	
	/**
	 * Creates the file and adds the passed type to
	 * its list of types.
	 */
	public TypedFile(String file, String type) {
		super(file);
		this.types = new Vector<String>();
		types.add(type);
	}
			
	@Override
	public String getParent() {
		// To ensure compatibilty on different operating systems, change path seperator 
		if ((super.getParent() != null) && (osName.indexOf("Windows") != -1))
			return super.getParent().replace("\\","/");
		else			
			return super.getParent();
	}

	@Override
	public String getPath() {
		// To ensure compatibilty on different operating systems, change path seperator 
		if ((super.getPath() != null) && (osName.indexOf("Windows") != -1))
			return super.getPath().replace("\\","/");
		else			
			return super.getPath();
	}

	/**
	 * Creates the file.
	 */
	public TypedFile(String file) {
		super(file);
		this.types = new Vector<String>();
	}
	
	/**
	 * Removes all types from this file and sets the passed type as its type.
	 */
	public void setType(String type) {
		this.types.clear();
		this.types.add(type);
	}
	
	/**
	 * Creates the file and adds the passed types to
	 * its list of types.
	 */
	public TypedFile(String file, Vector<String> types) {
		super(file);
		this.types = new Vector<String>();
		this.types.addAll(types);
	}

	public Vector<String> getTypes() {
		return this.types;
	}
	
}
