/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.graph;

import gui.helper.Grid;
import helper.SmallHelpers;

import java.io.File;
import java.util.Properties;
import java.util.Vector;

import core.TypedFile;
import core.storage.ConfigurationXMLReader;

/**
 * This class defines the properties of an input file node.
 * 
 * InpuFileNodes are the first nodes of a workflow and have no predecessors. They
 * are used to specify files that are used as input for the workflow.
 * InpuFileNodes can have one of the following types: Trace, XML-MAP, XML-Dist, 
 * XML-ATRA, XML-PH, XML-ARIMA and are mostly used to load a trace file.
 */

public class InputFileNode extends FileNode {
	private static final long serialVersionUID = 1L;
	
	/**
	 * Creates the node according to the passed values and sets its name to "I".
	 */
	public InputFileNode(int px, int py, ConfigurationXMLReader reader, Grid grid, int id,
			Graph graph, TypedFile inputFile) {
		super(px, py, reader, grid, id, graph);
		this.name = "I";
		
		this.externalFileName = inputFile;
		this.externalFileName.setType(reader.getInputConverterInputTypeByID(id));

		this.xmlOutputFile = new TypedFile(externalFileName.getName() + reader.getInputConverterOutputSuffixByID(id), getOutputFileTypes().get(0));
	}
	
	@Override
	public String getXMLRepresentationOfNode(int id){		
		String xmlDescription = "";
		xmlDescription+="<node>\n<id> "+id+" </id>\n";
		xmlDescription+="<name> "+this.getName()+" </name>\n";
		xmlDescription+="<coords> "+this.getX()+" "+this.getY()+" </coords>\n";
		xmlDescription+="<gridcoords> "+ this.gridX +" "+ this.gridY +" </gridcoords>\n";
		xmlDescription+="<input>\n";
		xmlDescription+="\t<file>\n";
		xmlDescription+="\t\t<name> "+this.externalFileName.getName()+" </name>\n";
		if ((this.externalFileName.getParent() != null) && (!this.externalFileName.getParent().equals("")))
			xmlDescription+="\t\t<path> "+this.externalFileName.getParent() + File.separator +" </path>\n";
		xmlDescription+="\t\t<type> "+this.externalFileName.getTypes().get(0) +" </type>\n";
		xmlDescription+="\t</file>\n";
		xmlDescription+="</input>\n";
		xmlDescription+="</node>";
		
		return xmlDescription;
	}
	@Override
	public String getCommandLineCall(String softwarePath, String resultPath) {
		String result = "\""+softwarePath + reader.getInputConverterBinaryByID(this.referenceID)+"\"";
		if ((xmlOutputFile.getParent() == null) || (xmlOutputFile.getParent().equals("")))
			result = result + " \"" + externalFileName.getPath() + "\" \"" + resultPath + xmlOutputFile.getName() + "\"";
		else
			result = result + " \"" + externalFileName.getPath() + "\" \"" + xmlOutputFile.getPath() + "\"";
		return result;
	}
	
	@Override
	public Vector<String> getInputFileTypes() {
		return this.externalFileName.getTypes();
	}

	@Override
	public Vector<String> getOutputFileTypes() {
		Vector<String> result = new Vector<String>();
		result.add(reader.getInputConverterOutputTypeByID(referenceID));
		return result;
	}

	@Override
	public void setConverterID(int newConverterID) {
		this.referenceID = newConverterID;
		this.externalFileName.setType(reader.getInputConverterInputTypeByID(this.referenceID));
		for (Edge curEdge : outgoingEdges)
			curEdge.refreshType();
	}

	public Vector<String> getCommonOutgoingTypes() {
		Vector<String> result = null;
		for (Edge curEdge : outgoingEdges) {
			GraphNode curFromNode = curEdge.getTo();
			Vector<String> curNodeInputFileTypes = curFromNode.getInputFileTypes();
			result = SmallHelpers.intersect(result, curNodeInputFileTypes);
		}
		return result;
	}


}
