/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.graph;

import java.io.File;


import java.util.Properties;
import java.util.Vector;

import gui.helper.Grid;
import helper.SmallHelpers;
import core.TypedFile;
import core.storage.ConfigurationXMLReader;



/**
 * This abstract class defines the properties of an output file node.
 * 
 * OutputFileNodes mark the end of a workflow and have no successors, they
 * represent files that are used to specify the results of a workflow that 
 * the user is interested in, such as fitted models or plots with characteristics
 * of the models. They have a name and a location where they should be saved.
 * OutputFileNodes can have the following output formats: 
 * XML-Trace, PS, Latex, Trace, Map.
 */

public class OutputFileNode extends FileNode {
	private static final long serialVersionUID = 1L;
	
	/**
	 * Creates the node according to the passed values and sets its name to "O".
	 */
	public OutputFileNode(int px, int py, ConfigurationXMLReader xmlReader, Grid grid,
			int id, Graph graph, TypedFile fileName) {
		super(px, py, xmlReader, grid, id, graph);
		this.name = "O";
		
		this.externalFileName = fileName;
		this.externalFileName.setType(reader.getOutputConverterOutputTypeByID(id));
		this.xmlOutputFile = null;
	}
		
	@Override
	public String getCommandLineCall(String softwarePath, String resultPath) {
		GraphNode inputNode = this.incomingEdges.get(0).getFrom();
		if (inputNode instanceof JobNode) {
			String result = "\"" +softwarePath + reader.getOutputConverterBinaryByID(this.referenceID)+"\"";
			TypedFile inputNodeXMLOutputFile = inputNode.getXMLOutputFile();
			if ((inputNodeXMLOutputFile.getParent() == null) || (inputNodeXMLOutputFile.getParent().equals("")))
				result = result + " \"" + resultPath + inputNodeXMLOutputFile.getName() + "\" \"" + externalFileName.getPath() + "\"";
			else
				result = result + " \"" + inputNodeXMLOutputFile.getPath() + "\" \"" + externalFileName.getPath() + "\"";
		
			return result;
		}
		
		return null;
	}
	
	@Override
	public String getXMLRepresentationOfNode(int id) {
		String xmlDescription = "";
		xmlDescription+="<node>\n<id> "+id+" </id>\n";
		xmlDescription+="<name> "+this.getName()+" </name>\n";
		xmlDescription+="<coords> "+this.getX()+" "+this.getY()+" </coords>\n";
		xmlDescription+="<gridcoords> "+ this.gridX +" "+ this.gridY +" </gridcoords>\n";
		xmlDescription+="<output>\n";
		xmlDescription+="\t<file>\n";
		xmlDescription+="\t\t<name> "+this.getExternalFileName().getName()+" </name>\n";
		if ((this.externalFileName.getParent() != null) && (!this.externalFileName.getParent().equals("")))
			xmlDescription+="\t\t<path> "+this.externalFileName.getParent() + File.separator +" </path>\n";
		xmlDescription+="\t\t<type> "+reader.getOutputConverterOutputTypeByID(referenceID)+" </type>\n";
		xmlDescription+="\t</file>\n";
		xmlDescription+="</output>\n";
		xmlDescription+="</node>";
		
		return xmlDescription;
	}

	@Override
	public Vector<String> getInputFileTypes() {
		Vector<String> result = new Vector<String>();
		result.add(reader.getOutputConverterInputTypeByID(referenceID));
		return result;
	}

	@Override
	public Vector<String> getOutputFileTypes() {
		Vector<String> result = new Vector<String>();
		result.add(reader.getOutputConverterOutputTypeByID(referenceID));
		return result;
	}
	
	@Override
	public void setConverterID(int newConverterID) {
		this.referenceID = newConverterID;
		this.externalFileName.setType(reader.getOutputConverterOutputTypeByID(this.referenceID));
		for (Edge curEdge : incomingEdges)
			curEdge.refreshType();
	}

	public Vector<String> getCommonIncomingTypes() {
		Vector<String> result = null;
		for (Edge curEdge : incomingEdges) {
			GraphNode curFromNode = curEdge.getFrom();
			Vector<String> curNodeOutputFileTypes = curFromNode.getOutputFileTypes();
			result = SmallHelpers.intersect(result, curNodeOutputFileTypes);
		}
		return result;
	}

}
