/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;

import core.BooleanParameterGroup;

/**
 * This class defines the history object used to change the value of 
 * a BooleanParameterGroup.
 */

public class ChangeBooleanParameterGroupValuesHistoryObject extends HistoryObject {

	private static final long serialVersionUID = 1L;
	private BooleanParameterGroup group;
	private boolean newValue;
	private boolean oldValue;
	private String nodeName;
	
	public ChangeBooleanParameterGroupValuesHistoryObject(String nodeName, BooleanParameterGroup booleanParameterGroup, boolean newValue) {
		this.group = booleanParameterGroup;
		this.newValue = newValue;
		this.oldValue = group.isEnabled();
		this.nodeName = nodeName;
	}

	@Override
	public HistoryObject createUndoObject() {
		return new ChangeBooleanParameterGroupValuesHistoryObject(nodeName, group, oldValue);
	}

	@Override
	public String getInformationString() {
		if (newValue)
			return "Set Parameter (" + group.getName() + ") of Job (" + nodeName + ")";
		else
			return "Unset Parameter (" + group.getName() + ") of Job (" + nodeName + ")";
	}

	@Override
	public void performAction() {
		group.setEnable(newValue);
	}

}
