/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;
import java.util.Vector;
import core.DynamicTextParameter;
import core.graph.JobNode;

/**
 * This class defines the history object used to change the value of one
 * dynamic text parameter.
*/

public class ChangeDynamicTextParameterValueHistoryObject extends HistoryObject {

	private static final long serialVersionUID = 1L;
	private DynamicTextParameter parameter;
	private Vector<String> newValues;
	private Vector<String> oldValues;

	public ChangeDynamicTextParameterValueHistoryObject(DynamicTextParameter dynamicParameter,
			Vector<String> newValues) {
		this.parameter = dynamicParameter;
		this.newValues = newValues;
		this.oldValues = new Vector<String>(parameter.getValues());
	}

	@Override
	public HistoryObject createUndoObject() {
		return new ChangeDynamicTextParameterValueHistoryObject(parameter, oldValues);
	}

	@Override
	public String getInformationString() {
		String newValuesString = "";
		String oldValuesString = "";
		
		for (String curValue : oldValues)
			oldValuesString = oldValuesString + curValue + "; ";
		if (oldValuesString.lastIndexOf(";") > -1)
			oldValuesString = oldValuesString.substring(0, oldValuesString.lastIndexOf(";") - 2);
		
		for (String curValue : newValues)
			newValuesString = newValuesString + curValue + "; ";
		if (newValuesString.lastIndexOf(";") > -1)
			newValuesString = newValuesString.substring(0, newValuesString.lastIndexOf(";") - 2);
		return newValuesString + " -> " + oldValuesString;
		//return "Change Text Parameter (" + parameter.getName() + ") of Node (" + node.getName() + ") from " + oldValues + " to " + newValues;	
	}

	@Override
	public void performAction() {
		Vector<String> tmpNewValues = new Vector<String>(newValues);
		parameter.setValues(tmpNewValues);
	}
}
