/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;
import core.ParameterGroup;

/**
 * This class defines the history object used to change the visibility of
 * a ParameterGroup.
 */

public class ChangeParameterGroupVisibility  extends HistoryObject {
	private static final long serialVersionUID = 1L;
	private ParameterGroup  group;
	private boolean newValue;
	private boolean oldValue;
	private String nodeName;
	
	public ChangeParameterGroupVisibility(String nodeName, ParameterGroup  textParameterGroup, boolean newValue) {
		this.group = textParameterGroup;
		this.newValue = newValue;
		this.oldValue = group.isVisible();
		this.nodeName = nodeName;
	}

	@Override
	public HistoryObject createUndoObject() {
		return new ChangeParameterGroupVisibility(nodeName, group, oldValue);
	}

	@Override
	public String getInformationString() {
		if (newValue)
			return "Enable Visibilty of Parameter (" + group.getName() + ") of Job Node (" + nodeName + ")";
		else
			return "Disable Visibilty of Parameter (" + group.getName() + ") of Job Node (" + nodeName + ")";
	}

	@Override
	public void performAction() {
		group.setVisible(newValue);
	}
}
