/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;
import core.StaticTextParameter;
import core.graph.JobNode;

/**
 * This class defines the history object used to change the value of one
 * static text parameter.
*/

public class ChangeStaticTextParameterValueHistoryObject extends HistoryObject {

	private static final long serialVersionUID = 1L;
	private StaticTextParameter parameter;
	private String newValue;
	private String oldValue;
	private JobNode node;

	public ChangeStaticTextParameterValueHistoryObject(StaticTextParameter staticParameter,
			String newValue) {
		this.parameter = staticParameter;
		this.newValue = newValue;
		this.oldValue = parameter.getValue();
	}

	@Override
	public HistoryObject createUndoObject() {
		return new ChangeStaticTextParameterValueHistoryObject(parameter, oldValue);
	}

	@Override
	public String getInformationString() {
		//return "Change Text Parameter (" + parameter.getName() + ") of Node (" + node.getName() + ") from " + oldValue + " to " + newValue;	
		return newValue + " -> " + oldValue;
	}

	@Override
	public void performAction() {
		parameter.setValue(newValue);
	}
}
