/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;
import java.util.Vector;
import core.TextParameterGroup;

/**
 * This class defines the history object used to change the values of a
 * TextParameterGroup of a node. The changes are represented by an array of 
 * HistoryObjects, each representing the change of one of the groups parameters.
 */
public class ChangeTextParameterGroupValuesHistoryObject extends HistoryObject {
	private static final long serialVersionUID = 1L;
	private TextParameterGroup group;
	private Vector<HistoryObject> changes;
	private String nodeName;

	public ChangeTextParameterGroupValuesHistoryObject(String nodeName, TextParameterGroup textParameterGroup, Vector<HistoryObject> changes) {
		super();
		this.nodeName = nodeName;
		this.group = textParameterGroup;
		this.changes = changes;
	}

	@Override
	public HistoryObject createUndoObject() {
		Vector<HistoryObject> undoChanges = new Vector<HistoryObject>();
		for (HistoryObject curObject : changes) {
			undoChanges.add(curObject.createUndoObject());
		}
		return new ChangeTextParameterGroupValuesHistoryObject(nodeName, group, undoChanges);
	}

	@Override
	public String getInformationString() {
		String result = "Change Value of Parameter (" + group.getName() + ")";
		// TODO Vollstndig implementieren
		/*
		for (HistoryObject curObject : changes) {
			if (curObject != null)
				result = result + curObject.getInformationString() + ", ";
		}
		if (result.lastIndexOf(";") > -1)
			result = result.substring(0, result.lastIndexOf(";") - 2);
		*/
		result = result + " of Job (" + nodeName + ")";
		return result;
	}

	@Override
	public void performAction() {
		for (HistoryObject curObject : changes) {
			if (curObject != null)
				curObject.performAction();
		}
	}	
}
