/*
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package core.history;

import java.awt.Point;

import core.graph.BasicNode;
import core.graph.GraphNode;
import core.graph.Graph;
import core.graph.PointNode;

/**
 * This class defines the history object used to change the grid position
 * of a node.
*/
public class MoveNodeHistoryObject extends HistoryObject {

	/**
	 * Node whose grid position will be changed.
	 */
	private BasicNode node;

	/**
	 * New grid position.
	 */
	private Point newGridPosition;
	
	/**
	 * Old grid position.
	 */
	private Point oldGridPosition;
	
	private Graph graph;
	
	public MoveNodeHistoryObject(Graph graph, BasicNode node, Point oldGridPosition, Point newGridPosition) {
		this.graph = graph;
		this.node = node;
		this.newGridPosition = newGridPosition;
		this.oldGridPosition = oldGridPosition;
	}

	@Override
	public HistoryObject createUndoObject() {
		return new MoveNodeHistoryObject(graph, node, newGridPosition, oldGridPosition);
	}

	@Override
	public void performAction() {
		node.moveToGridCoordinates(newGridPosition);
	}

	@Override
	public String getInformationString() {
		if (node instanceof GraphNode)
			return "Move Node (" + ((GraphNode)node).getName() + ") from Cell [" + oldGridPosition.x + ", " + oldGridPosition.y + "] to Cell [" + newGridPosition.x + ", " + newGridPosition.y + "]";
		else if (node instanceof PointNode) 
			return "Move EdgePoint (" + ((PointNode)node).getEdge().getDisplayFriendlyName() + ") from Cell [" + oldGridPosition.x + ", " + oldGridPosition.y + "] to Cell [" + newGridPosition.x + ", " + newGridPosition.y + "]";
		else
			return "";
	}
}
