/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;
import core.graph.Edge;
import core.graph.Graph;

/**
 * This class defines the history object used to remove a connection 
 * between two nodes as represented by an edge.
 */

public class RemoveConnectionHistoryObject extends HistoryObject {

	private static final long serialVersionUID = 1L;
	private Edge edge;
	private Graph graph;
	
	public RemoveConnectionHistoryObject(Edge edge, Graph graph) {
		this.graph = graph;
		this.edge = edge;
	}

	@Override	
	public HistoryObject createUndoObject() {
		return new ConnectNodeHistoryObject(edge, graph);
	}

	@Override
	public String getInformationString() {
		return "Remove connection (" + edge.getDisplayFriendlyName() + ")";
	}
	
	@Override
	public void performAction() {
		graph.removeEdge(edge);
	}

}
