/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;

import java.util.Vector;

import core.graph.BasicNode;
import core.graph.Edge;
import core.graph.Graph;
import core.graph.GraphNode;
import core.graph.InputFileNode;
import core.graph.OutputFileNode;
import core.graph.PointNode;

/**
 * This class defines the history object used to remove a node
 * from the graph.
 */
public class RemoveNodeHistoryObject extends HistoryObject {

	private static final long serialVersionUID = 1L;
	private BasicNode node;
	private Vector<Edge> connectedEdges;
	private Graph graph;

	public RemoveNodeHistoryObject(BasicNode node, Graph graph) {
		this.graph = graph;
		this.node = node;
		this.connectedEdges = graph.getAllEdgesConnectedToNode(node);		
	}

	@Override
	public HistoryObject createUndoObject() {
		if (node instanceof PointNode)
			return new NewPointNodeHistoryObject(((PointNode) node).getEdge(), ((PointNode) node).getLeftNeighbour(), graph);	
		else
			return new NewNodeHistoryObject((GraphNode) node, connectedEdges, graph);
	}

	@Override
	public String getInformationString() {
		if (node instanceof PointNode)
			return "Remove EdgePoint on Edge (" + (((PointNode) node).getEdge().getDisplayFriendlyName()) + ")";
		else if (node instanceof InputFileNode)
			return "Remove Input Node (" + ((InputFileNode)node).getExternalFileName().getName() + ")";		
		else if (node instanceof OutputFileNode)
			return "Remove Output Node (" + ((OutputFileNode)node).getExternalFileName().getName() + ")";		
		else
			return "Remove Node (" + node.getName() + ")";
	}

	@Override
	public void performAction() {
		graph.removeNode(node);

		for (Edge curEdge : connectedEdges) {	
			graph.removeEdge(curEdge);
		}
	}

}
