/*
 * 
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package core.history;

import core.graph.FileNode;
import core.graph.Graph;
import core.graph.InputFileNode;

public class SetConverterIDHistoryObject extends HistoryObject {
	private static final long serialVersionUID = 1L;
	private int oldConverterID;
	private int newConverterID;
	private FileNode node;
	private Graph graph;
	

	public SetConverterIDHistoryObject(FileNode markedAbstractNode,
			int newConverterID, Graph graph) {
		this.graph = graph;
		this.oldConverterID = markedAbstractNode.getConverterID();
		this.newConverterID = newConverterID;
		this.node = markedAbstractNode;
		
	}

	@Override
	public HistoryObject createUndoObject() {
		return new SetConverterIDHistoryObject(node, oldConverterID, graph);
	}

	@Override
	public void performAction() {
		node.setConverterID(newConverterID);
	}

	@Override
	public String getInformationString() {
		
		if (node instanceof InputFileNode)
			return "Change Type of Input File (" + node.getInformativeName() + ") from " + graph.getReader().getInputConverterInputTypeByID(oldConverterID) + " to " + graph.getReader().getInputConverterInputTypeByID(newConverterID);
		else
			return "Change Type of Output File (" + node.getInformativeName() + ") from " + graph.getReader().getOutputConverterOutputTypeByID(oldConverterID) + " to " + graph.getReader().getOutputConverterOutputTypeByID(newConverterID);
	}

}
