/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;

import java.io.File;
import core.graph.FileNode;
import core.graph.Graph;
import core.graph.InputFileNode;

/**
 * This class defines the history object used to set a nodes
 * the external FileName and the ConverterID.
 */

public class SetExternalFileNameHistoryObject extends
		HistoryObject {

	private static final long serialVersionUID = 1L;
	private String newFileName;
	private String oldFileName;
	private FileNode node;

	public SetExternalFileNameHistoryObject(FileNode node,
			String newFileName) {
		this.node = node;
		this.oldFileName = node.getExternalFileName().getPath();
		this.newFileName = newFileName;	
	}


	@Override
	public HistoryObject createUndoObject() {
		return new SetExternalFileNameHistoryObject(node, oldFileName);
	}

	@Override
	public String getInformationString() {
		if (node instanceof InputFileNode)
			return "Change File Name of Input Node from " + oldFileName + " to " + newFileName;
		else
			return "Change File Name of Output Node from " + oldFileName + " to " + newFileName;
	}

	@Override
	public void performAction() {
		node.setExternalFileName(newFileName);		
	}
}
