/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package core.history;
import core.graph.Edge;
import core.graph.Graph;

/**
 * This class defines the history object used to set a file name.
 */
public class SetFileNameHistoryObject extends HistoryObject {
	
	private static final long serialVersionUID = 1L;
	
	private String newName;
	private String oldName;
	private Edge edge;

	public SetFileNameHistoryObject(Edge edge, String newName) {
		this.edge = edge;
		this.oldName = edge.getFileName().getPath();
		this.newName = newName;
	}

	@Override
	public HistoryObject createUndoObject() {
		return new SetFileNameHistoryObject(edge, oldName);
	}

	@Override
	public void performAction() {
		edge.getFrom().setXMLFileName(newName);

	}

	@Override
	public String getInformationString() {
		return "Change File Name of Edge (" + edge.getDisplayFriendlyName() + ") from " + oldName + " to " + newName;
	}


}
