/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package gui;

import java.awt.BorderLayout;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JEditorPane;
import javax.swing.JComponent;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.IOException;
import java.util.Calendar;
import java.util.GregorianCalendar;

/**
 * This class defines the properties of the "About ProFiDo" frame.
 * 
 * It creates the frame which is shown after a click on the "About ProFiDo" item.
 */
public class AboutFrame extends JFrame{
	// TODO Improve design
	
	private static final long serialVersionUID = 1L;	
	public static String PROFIDO_VERSION = "1.2";
	public static String PROFIDO_VERSION_YEAR = "2012";
	public static String NAME = "ProFiDo";

	
	/** 
	 * The panel used to display the actual informations about ProFiDo.
	 */
	private JEditorPane contentPanel;
	private JPanel buttonPanel;

	/**
	 * The ok button used to close this panel.
	 */
	private JButton okButton;
	
	/**
	 * The scroll pane used to enable scroll bars within the about text.
	 */
	protected JScrollPane scrollpane;
	
	/**
	 * Creates and initilazes the panel according to the passed size.
	 */
	public AboutFrame(int width, int height) {
		initialize(width, height);
	}
	
	/**
	 * Initializes all components used by this panel and adds them to 
	 * its content pane.
	 */
	public void initialize(int width, int height){
		this.setSize(width, height);
		this.getContentPane().add(getScrollPane(), BorderLayout.NORTH);
		this.getContentPane().add(getButtonPanel(), BorderLayout.SOUTH);
		this.setTitle("About ProFiDo");	
	}

	/**
	 * Creates (if necessary) and returns the contenPanel.
	 */
	protected JComponent getContentPanel() {
		if(contentPanel==null){
			contentPanel= new JEditorPane("text/html", getMessage());
			contentPanel.setEditable(false);
			contentPanel.setCaretPosition(0);
		}
		return contentPanel;
	}
	
	/**
	 * Creates (if necessary) and returns the buttonPanel-
	 */
	protected JPanel getButtonPanel() {
		if (buttonPanel == null) {
			buttonPanel = new JPanel();
			buttonPanel.add(getOkButton(this), BorderLayout.CENTER);
		}
		return buttonPanel;
	}

	/**
	 * Creates (if necessary) and returns the okButton-
	 */
	protected JButton getOkButton(final JFrame frame) {
		if(okButton==null){
			okButton=new JButton("OK");
			okButton.setPreferredSize(new Dimension(100, 50));
			okButton.addActionListener(new ActionListener() {				
				@Override
				public void actionPerformed(ActionEvent e) {
					frame.setVisible(false);
				}
			});
		}
		return okButton;
	}
	
	/**
	 * Reads and returns the content of "aboutFile.txt" in order 
	 * to display it in the about window.
	 */	
	protected String getMessage(){
		String message = "";
		InputStream is = null;
		String path = "";
		try {
			path = "/aboutFile.txt";
			is = AboutFrame.class.getResourceAsStream(path);
			BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(is));
			while (bufferedReader.ready()) {
				message += bufferedReader.readLine();
			}
			
			// Dispose all the resources after using them.
			is.close();
			bufferedReader.close();
		} catch (IOException e) {
		}
		
		message = message.replace("VERSION", HelpFrame.PROFIDO_VERSION);
		message = message.replace("YEAR", HelpFrame.PROFIDO_VERSION_YEAR);
		return message;
	}

	public JScrollPane getScrollPane(){
		if(scrollpane==null){
			scrollpane = new JScrollPane(getContentPanel());
			scrollpane.setPreferredSize(new Dimension(700, 600));
		}
		return scrollpane;
	}
	

}
