/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package gui;

import javax.swing.JPanel;
import javax.swing.JFrame;
import core.graph.Edge;
import core.graph.Graph;
import core.storage.ConfigurationXMLReader;

/**
 * This class defines the properties of the "Plotter" frame 
 * 
 */


/**
 * This class defines the properties of the "Edge Plotter" frame which is shown 
 * after a click on the "Plotter" item in the popup menu of an edge. The actual
 * content is created by the EdgePlotterPanel class.
 */


public class EdgePlotterFrame extends JFrame  {
	private static final long serialVersionUID = 1L;
	private JPanel contentPanel = null;
		
	/**
	 * Creates the frame and sets its title according to the corresponding
	 * edge. 
	 * 
	 * @param xmlReader the xml reader used by the application
	 * @param graph current workflow as represented by the graph
	 * @param edge corresponding edge
	 * @param workflowPanel the main workspace panel used by the GUI
	 */
	public EdgePlotterFrame(final ConfigurationXMLReader xmlReader, final Graph graph, final Edge edge, final WorkflowPanel workflowPanel) {
		super();

		this.setContentPane(getJContentPane(xmlReader,graph,edge, workflowPanel));
		this.setTitle("Plotter - " + edge.getTooltipText());	
	}

	/** 
	 * Creates and returns an instance of EdgePlotterPanel which is the 
	 * content panel of this frame.
	 * 
	 * Uses parameters as described in the constructor.
	 */
	private JPanel getJContentPane(ConfigurationXMLReader xmlReader, Graph graph, Edge edge, WorkflowPanel workflowPanel) {
		if (contentPanel == null) {
			contentPanel = new EdgePlotterPanel(xmlReader, graph, edge, workflowPanel, this);
			this.setSize(500,((EdgePlotterPanel)contentPanel).getDesiredHeight() + 40);
			contentPanel.setLayout(null);
		}
		return contentPanel;
	}

	public void finished() {
		this.dispose();
	}
	
}
