/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package gui;


import java.awt.Rectangle;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.util.Vector;

import core.BooleanParameterGroup;
import core.graph.JobNode;
import core.history.ChangeBooleanParameterGroupValuesHistoryObject;
import core.history.ChangeParameterGroupVisibility;
import core.history.HistoryObject;

/**
 * This class defines the properties of the panel for editing one BooleanParameterGroup.
 * It contains no additional elements as the value of the parameter group is defined
 * by the state of the enable attribute.
 */

public class EditOneBooleanParameterPanel extends EditOneParameterPanel {
	private static final long serialVersionUID = 1L;

	/**
	 * Creates and initializes the panel.
	 */	
	public EditOneBooleanParameterPanel(JobNode node, BooleanParameterGroup group, EditJobPanel editJobPanel,WorkflowPanel workflowPanel) {
		super(node, editJobPanel,workflowPanel);	
		myParameterGroup = group;
		initialize();
	}
	
	/**
	 * Initializes all components used by this panel and adds them to 
	 * its content pane.
	 */
	protected void initialize() {
		super.initialize();
		enableCheckBox.setText("Set");
		this.addComponentListener(new ComponentAdapter() {
	        public void componentResized(ComponentEvent evt) {
	        	updatePositions();
	        }
	    });
		updatePositions();

	}
	
	@Override
	public void updatePositions() {
		int topMargin = 13;
		int bottomMargin = 4;

		int leftMargin = 6;
		int rightMargin = 6;
		int componentLeftSpacing = 2;
		int componentTopSpacing = 2;
		
		int contentWidth = this.getWidth() - leftMargin - rightMargin;
		int labelPositionCorrection = 4;
		
		// Define desired component sizes
		int helpLabelWidth = 10;
		//int enableCheckBoxWidth = 74;
		int visibleCheckBoxWidth = 76;
		
		int labelHeight = 16;
		//int textFieldHeight = 28;
		int checkBoxHeight = 23;
			
		if (helpLabel != null) {
			helpLabel.setBounds(new Rectangle(leftMargin + labelPositionCorrection + contentWidth - helpLabelWidth, topMargin, helpLabelWidth, labelHeight));
		}
		
		int secondRowTopPosition = topMargin + labelHeight + componentTopSpacing;
		
		if (visibleCheckBox != null) {
			visibleCheckBox.setBounds(new Rectangle(this.getWidth() - rightMargin - visibleCheckBoxWidth, secondRowTopPosition, visibleCheckBoxWidth, checkBoxHeight));
		}
				
		if (enableCheckBox != null) {	
			enableCheckBox.setBounds(new Rectangle(leftMargin, secondRowTopPosition, contentWidth - componentLeftSpacing - visibleCheckBoxWidth, checkBoxHeight));
		}
			
		desiredHeight = enableCheckBox.getY() + enableCheckBox.getHeight() + bottomMargin;

	}

	/**
	 * This method sets the values of the text field and the check boxes 
	 * to the default values.
	 */
	public void showDefaultValues() {
		enableCheckBox.setSelected(((BooleanParameterGroup) myParameterGroup).getDefaultValueEnabled());
		visibleCheckBox.setSelected(((BooleanParameterGroup) myParameterGroup).getDefaultVisibility());
	}
	
	/**
	 * This method determines the check boxes whose values has been changed and creates
	 * and return a history object to inherit these changes.
	 */
	public Vector <HistoryObject> createHistoryObjectToInheritTemporaryBooleanParameterCheckBoxValues() {
		
		Vector <HistoryObject> curPanelHistoryObject = new Vector<HistoryObject>()  ;
		
		if (enableCheckBox.isSelected() != ((BooleanParameterGroup)myParameterGroup).isEnabled() && visibleCheckBox.isSelected()!= ((BooleanParameterGroup)myParameterGroup).isVisible()){
			
			curPanelHistoryObject.add(new ChangeBooleanParameterGroupValuesHistoryObject(node.getName(), (BooleanParameterGroup)myParameterGroup, enableCheckBox.isSelected()));
			curPanelHistoryObject.add(new ChangeParameterGroupVisibility(node.getName(), (BooleanParameterGroup)myParameterGroup, visibleCheckBox.isSelected()));
			//System.out.println("E & V");

			}
		
		else if (enableCheckBox.isSelected() != ((BooleanParameterGroup)myParameterGroup).isEnabled() && !(visibleCheckBox.isSelected()!= ((BooleanParameterGroup)myParameterGroup).isVisible())){
			
			curPanelHistoryObject.add(new ChangeBooleanParameterGroupValuesHistoryObject(node.getName(), (BooleanParameterGroup)myParameterGroup, enableCheckBox.isSelected()));
			//System.out.println("E & !V");
		}
		
		else if (!(enableCheckBox.isSelected() != ((BooleanParameterGroup)myParameterGroup).isEnabled()) && visibleCheckBox.isSelected()!= ((BooleanParameterGroup)myParameterGroup).isVisible()){
			
			curPanelHistoryObject.add(new ChangeParameterGroupVisibility(node.getName(), (BooleanParameterGroup)myParameterGroup, visibleCheckBox.isSelected()));
			//System.out.println("!E & V");
		}
		
		return curPanelHistoryObject;
	}
	
	
	@Override
	public HistoryObject createHistoryObjectToInheritTemporaryValues() {
		if (enableCheckBox.isSelected() != ((BooleanParameterGroup)myParameterGroup).isEnabled())
			return new ChangeBooleanParameterGroupValuesHistoryObject(node.getName(), (BooleanParameterGroup)myParameterGroup, enableCheckBox.isSelected());
		else
			return null;
	}
		
	/**
	 * This method sets the values of the text field and the check boxes to the 
	 * last stored values.
	 */
	public void showLastValues() {
		enableCheckBox.setSelected(((BooleanParameterGroup) myParameterGroup).isEnabled());
		visibleCheckBox.setSelected(((BooleanParameterGroup) myParameterGroup).isVisible());
	}



}  