/*
 * 
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package gui;

import java.awt.Choice;
import java.awt.Rectangle;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.JLabel;
import javax.swing.JTextField;

import core.BooleanParameterGroup;
import core.SelectParameterGroup;
import core.TextParameterGroup;
import core.graph.JobNode;
import core.history.ChangeParameterGroupVisibility;
import core.history.ChangeParameterGroupEnable;
import core.history.ChangeTextParameterGroupValuesHistoryObject;
import core.history.HistoryObject;
import core.history.ChangeSelectParameterGroupValuesHistoryObject;


/**
 * This class defines the properties of the panel for editing one SelectParameterGroup.
 * It contains a select box showing all possible values.
 */

public class EditOneSelectParameterPanel extends EditOneParameterPanel {
	/**
	 * Label for displaying additional informations.
	 */
	private JLabel infoLabel = null;
	
	/**
	 * Choice box displaying all possible values.
	 */
	private Choice choice = null;

	/**
	 * Creates and initializes the panel.
	 */
	public EditOneSelectParameterPanel(JobNode node, SelectParameterGroup group,EditJobPanel editJobPanel,WorkflowPanel workflowPanel) {		
		super(node, editJobPanel, workflowPanel);
		myParameterGroup = group;

		initialize();
		writeChoice();
	}

	/**
	 * Initializes all components used by this panel and adds them to 
	 * its content pane.
	 */
	public void initialize() {
		super.initialize();
		infoLabel = new JLabel();
		infoLabel.setBounds(new Rectangle(11, 14, 304, 16));
		updateInfoLabelText();
		this.add(infoLabel, null);
		this.add(getChoiceField(),null);

		enableCheckBox.setText("Enable");

		this.addComponentListener(new ComponentAdapter() {
			public void componentResized(ComponentEvent evt) {
				updatePositions();
			}
		});
		updatePositions();
	}


	public Choice getChoiceField() {
		if ((choice==null) && (myParameterGroup instanceof SelectParameterGroup)) {
			choice = new Choice();
			choice.setBounds(new Rectangle(22, 37, 174, 28));
			proceedChoice();

		}
		return choice;
	}

	/**
	 * This method prints all possible file types to the choice box.
	 */
	public void proceedChoice(){
		Vector<String> list = ((SelectParameterGroup)myParameterGroup).getChoices() ;

		for(int i=0 ; i< list.size() ; i++) {
			choice.add(list.get(i));
		}

		updateInfoLabelText();
	}


	private void updateInfoLabelText() {
		infoLabel.setText("Format: " + ((SelectParameterGroup)myParameterGroup).getFormat() + " (Result: " + ((SelectParameterGroup) myParameterGroup).getCommandlineCallString() + ")");		
	}

	/**
	 * Updates the position of all components on this panel.
	 */
	public void updatePositions() {
		int topMargin = 13;
		int bottomMargin = 4;

		int leftMargin = 6;
		int rightMargin = 6;
		int componentLeftSpacing = 2;
		int componentTopSpacing = 2;

		int contentWidth = this.getWidth() - leftMargin - rightMargin;
		int labelPositionCorrection = 4;

		// Define desired component sizes
		int helpLabelWidth = 10;
		int enableCheckBoxWidth = 74;
		int visibleCheckBoxWidth = 76;

		int labelHeight = 16;
		int textFieldHeight = 28;
		int checkBoxHeight = 23;

		// Calculate derived sizes and positions
		int checkBoxTopCorrection = (textFieldHeight - checkBoxHeight) / 2;

		if (infoLabel != null) {
			infoLabel.setBounds(new Rectangle(leftMargin + labelPositionCorrection, topMargin, contentWidth - componentLeftSpacing - helpLabelWidth, labelHeight));
		}

		if (helpLabel != null) {
			helpLabel.setBounds(new Rectangle(infoLabel.getX() + infoLabel.getWidth() + componentLeftSpacing, topMargin, helpLabelWidth, labelHeight));
		}

		int secondRowTopPosition = topMargin + labelHeight + componentTopSpacing;

		if (visibleCheckBox != null) {
			visibleCheckBox.setBounds(new Rectangle(this.getWidth() - rightMargin - visibleCheckBoxWidth, secondRowTopPosition + checkBoxTopCorrection, visibleCheckBoxWidth, checkBoxHeight));
		}

		if (enableCheckBox != null) {
			enableCheckBox.setBounds(new Rectangle(visibleCheckBox.getX() - componentLeftSpacing - enableCheckBoxWidth, secondRowTopPosition + checkBoxTopCorrection, enableCheckBoxWidth, checkBoxHeight));
		}

		if (choice != null) {
			choice.setBounds(new Rectangle(leftMargin, secondRowTopPosition, contentWidth - (2 * componentLeftSpacing) - enableCheckBoxWidth - visibleCheckBoxWidth, textFieldHeight));
		}			

		desiredHeight = choice.getY() + choice.getHeight() + bottomMargin;

	}

	/**
	 * This method sets the values of the text field and the check boxes 
	 * to the default values.
	 */
	public void showDefaultValues() {
		choice.select(((SelectParameterGroup) myParameterGroup).getDefaultChoice());
		enableCheckBox.setSelected(((SelectParameterGroup) myParameterGroup).getDefaultValueEnabled());
		visibleCheckBox.setSelected(((SelectParameterGroup) myParameterGroup).getDefaultVisibility());
	}

	/**
	 * This method sets the values of the text field and the check boxes to the 
	 * last stored values.
	 */
	public void showLastValues() {
		choice.select(((SelectParameterGroup) myParameterGroup).getChoiceValue());
		enableCheckBox.setSelected(((SelectParameterGroup) myParameterGroup).isEnabled());
		visibleCheckBox.setSelected(((SelectParameterGroup) myParameterGroup).isVisible());

	}

	/**
	 * This method determines the check boxes whose values has been changed and creates
	 * and return a history object to inherit these changes.
	 */
	public Vector <HistoryObject> createHistoryObjectToInheritTemporarySelectParameterCheckBoxValues() {

		Vector <HistoryObject> curPanelHistoryObject = new Vector<HistoryObject>()  ;

		if (enableCheckBox.isSelected() != ((SelectParameterGroup)myParameterGroup).isEnabled() && visibleCheckBox.isSelected()!= ((SelectParameterGroup)myParameterGroup).isVisible()){

			curPanelHistoryObject.add(new ChangeParameterGroupEnable(node.getName(), (SelectParameterGroup)myParameterGroup, enableCheckBox.isSelected()));
			curPanelHistoryObject.add(new ChangeParameterGroupVisibility(node.getName(), (SelectParameterGroup)myParameterGroup, visibleCheckBox.isSelected()));
			//System.out.println("E & V");

		}

		else if (enableCheckBox.isSelected() != ((SelectParameterGroup)myParameterGroup).isEnabled() && !(visibleCheckBox.isSelected()!= ((SelectParameterGroup)myParameterGroup).isVisible())){

			curPanelHistoryObject.add(new ChangeParameterGroupEnable(node.getName(), (SelectParameterGroup)myParameterGroup, enableCheckBox.isSelected()));
			//System.out.println("E & !V");
		}

		else if (!(enableCheckBox.isSelected() != ((SelectParameterGroup)myParameterGroup).isEnabled()) && visibleCheckBox.isSelected()!= ((SelectParameterGroup)myParameterGroup).isVisible()){

			curPanelHistoryObject.add(new ChangeParameterGroupVisibility(node.getName(), (SelectParameterGroup)myParameterGroup, visibleCheckBox.isSelected()));
			//System.out.println("!E & V");
		}

		return curPanelHistoryObject;
	}

	@Override
	public HistoryObject createHistoryObjectToInheritTemporaryValues() {		
		String newChoice = choice.getSelectedItem();
		String oldChoice= ((SelectParameterGroup) myParameterGroup).getChoiceValue();

		if (!(oldChoice.equals(newChoice))){


			return new ChangeSelectParameterGroupValuesHistoryObject(node, (SelectParameterGroup)myParameterGroup, newChoice, oldChoice );
		}
		else
			return null;

	}

	/**
	 * Select the current choice within the choices box.
	 */
	private void writeChoice() {
		choice.select(((SelectParameterGroup) myParameterGroup).getChoiceValue());
	}





}
