/*
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package gui;

import java.awt.Rectangle;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;

import javax.swing.DefaultListModel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JScrollPane;

import core.history.History;


/**
 * This class defines the properties of the "History" panel.
 * 
 * It is used to show a complete list of the changes made to the workflow and
 * enables the user to switch to selected states of the workflow. Furthermore
 * it provides a snapshot button performing a quick save of the current
 * state of the workflow within the users home directory.
 */
public class ShowHistoryPanel extends JPanel {
	static final long serialVersionUID = 1L;
	private JButton snapshotButton;
	private JButton moveButton;
	
	/**
	 * Reference to the history.
	 */
	private History history;
	
	private JScrollPane historyListScrollPane;
	
	private DefaultListModel historyListModel;
	
	/**
	 * List of history items.
	 */
	private JList historyList;

	/**
	 * Reference to the workflow panel.
	 */
	private WorkflowPanel workflowPanel;
	
	/**
	 * Creates the panel.
	 */
	public ShowHistoryPanel(History history, WorkflowPanel workflowPanel) {
		super();
		this.history = history;
		this.workflowPanel = workflowPanel;
		initialize();
	}
	
	/**
	 * Updates the position of all components on this panel.
	 */
	public void updatePositions() {
		int leftMargin = 5;
		int rightMargin = 5;
		int topMargin = 5;
		int bottomMargin = 5;
		
		int buttonLeftSpacing = 5;
		int buttonTopSpacing = 6; 
		int buttonHeigth = 20;	
	
		int contentWidth = this.getWidth() - (leftMargin + rightMargin);
		int historyHeight = this.getHeight() - (topMargin + bottomMargin + buttonHeigth + buttonTopSpacing);
		
		int buttonWidth = (contentWidth - buttonLeftSpacing) / 2;
		int buttonTopPosition = topMargin + bottomMargin + historyHeight;
				

		historyListScrollPane.setBounds(leftMargin, topMargin, contentWidth, historyHeight);
		moveButton.setBounds(leftMargin, buttonTopPosition, buttonWidth, buttonHeigth);
		snapshotButton.setBounds(leftMargin + buttonWidth + buttonLeftSpacing, buttonTopPosition, buttonWidth, buttonHeigth);
	}

	/**
	 * Initializes all components used by this panel and adds them to 
	 * its content pane.
	 */	
	private void initialize() {
		this.setSize(300, 200);
		this.setLayout(null);
		this.add(getSnapshotButton(), null);
		this.add(getMoveButton(), null);
		this.add(getHistoryListScrollPane(), null);
		
		this.addComponentListener(new ComponentAdapter() {
	        public void componentResized(ComponentEvent evt) {
	        	updatePositions();
	        }
	    });
	}
	 
	private JButton getSnapshotButton() {
		if (snapshotButton == null) {
			snapshotButton = new JButton("Create Snapshot");
			snapshotButton.setBounds(new Rectangle(187, 170, 75, 29));
			snapshotButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					workflowPanel.saveSnapshot();
				}
			});
		}
		return snapshotButton;
	}

	private JButton getMoveButton() {
		if (moveButton == null) {
			moveButton = new JButton("Move to selected state");
			moveButton.setBounds(new Rectangle(187, 170, 75, 29));
			moveButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					history.moveToSelectedIndex(historyList.getSelectedIndex());	
				}
			});
		}
		return moveButton;
	}
	
	private JScrollPane getHistoryListScrollPane() {
		if (historyListScrollPane == null) {
			historyListModel = new DefaultListModel();
			historyList = new JList(historyListModel);
			historyListScrollPane = new JScrollPane(historyList);
			historyListScrollPane.setBounds(100,10,100,100);
		}
		return historyListScrollPane;
	}

	public JList getHistoryList() {
		return historyList;
	}
	/**
	 * This method is called when this panel is about to close. 
	 * It notifies the history that this panel will vanish and removes
	 * the reference to this panels list model from the history.
	 */
	/*
	public void panelClosing() {
		history.setHistoryList(null);
	}*/

	public void setHistory(History history) {
		this.history = history;
		
	}
	
	
}

