/*
* 
* ProFiDo - The Processes Fitting Toolkit Dortmund
* Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
* 
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
*/

package gui.helper;

import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.util.Vector;

import javax.swing.SwingUtilities;

/**
 * This class defines the properties of text manager which provides methods to write text in different sizes.
 *
 */
public class TextManager {
	// TODO Optimize positioning of text
	
	static Font SMALL_FONT = new Font("Arial", 0, 10);
	static Font LARGE_FONT = new Font("Arial", 0, 12);
		
	/**
	 * This method writes the passed text in a large font.
	 * @param text text to be written
	 * @param x x-coordinate of the center of the text
	 * @param y y-coordinate of the center of the text
	 * @param pGraphics graphics to write the text on
	 * @param centered true if centered, else false
	 */
	public static void writeLargeText(String text, int x, int y,
			Graphics pGraphics, boolean centered) {
		Vector<String> tmpVector = new Vector<String>();
		tmpVector.add(text);
		writeLargeText(tmpVector, x, y, pGraphics, centered);
	}
	
	/**
	 * This method writes the passed text in a small font.
	 * @param text text to be written
	 * @param x x-coordinate of the center of the text
	 * @param y y-coordinate of the center of the text
	 * @param pGraphics graphics to write the text on
	 * @param centered true if centered, else false
	 */
	public static void writeSmallText(String text, int x,
			int y, Graphics pGraphics, boolean centered) {
		Vector<String> tmpVector = new Vector<String>();
		tmpVector.add(text);
		writeSmallText(tmpVector, x, y, pGraphics, centered);
		
	}

	
	/**
	 * This method writes the passed text in a small font.
	 * @param tooltipLines tooltip lines
	 * @param x x-coordinate of the center of the text
	 * @param y y-coordinate of the center of the text
	 * @param pGraphics graphics to write the text on
	 * @param centered true if centered, else false
	 */
	public static void writeSmallText(Vector<String> tooltipLines, int x,
			int y, Graphics pGraphics, boolean centered) {
		
		pGraphics.setFont(SMALL_FONT);		
		TextManager.writeText(tooltipLines, x, y, pGraphics, centered);
	}

	/**
	 * This method writes the passed text in a large font.
	 * @param tooltipLines tooltip lines
	 * @param x x-coordinate of the center of the text
	 * @param y y-coordinate of the center of the text
	 * @param pGraphics graphics to write the text on
	 * @param centered true if centered, else false
	 */
	public static void writeLargeText(Vector<String> tooltipLines, int x,
			int y, Graphics pGraphics, boolean centered) {

		pGraphics.setFont(LARGE_FONT);		
		TextManager.writeText(tooltipLines, x, y, pGraphics, centered);
	}
	
	/**
	 * This method writes text and positions it.
	 * @param tooltipLines tooltip lines
	 * @param x x-coordinate of the point
	 * @param y y-coordinate of the point
	 * @param pGraphics graphics
	 * @param centered true falls centered, else false
	 */
	private static void writeText(Vector<String> tooltipLines, int x, int y, Graphics pGraphics, boolean centered) {	
		FontMetrics curMetrics = pGraphics.getFontMetrics(pGraphics.getFont());
		double textXOffset = 0;
		double textYOffset = 0;
		String longestLine = "";
		for (String curLine : tooltipLines) {
			if (curLine.length() > longestLine.length())
				longestLine = curLine;
		}

		if (centered) {
			textXOffset = SwingUtilities.computeStringWidth(curMetrics, longestLine) / 2;
			textYOffset = 0.37 * curMetrics.getHeight();
		}

		double lineHeight = 0.8 * curMetrics.getHeight();
		double topPosition = y - (lineHeight * (tooltipLines.size() - 1)) + textYOffset;
		
		
		for (String curLine : tooltipLines) {
			// Process bold markings
			Font curFont = pGraphics.getFont();
			if ((curLine.startsWith("<b>")) && (curLine.endsWith("</b>"))) {
				pGraphics.setFont(new Font(curFont.getName(), Font.BOLD, curFont.getSize()));
				curLine = curLine.substring(3, curLine.length() - 4);
			} else {
				pGraphics.setFont(new Font(curFont.getName(), 0, curFont.getSize()));
			}

			pGraphics.drawString(curLine, (int)Math.round(x - textXOffset), (int) Math.round(topPosition));	
			topPosition = topPosition + lineHeight;
		}
	
	}
	


	
}
