/*
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package helper;

import java.io.File;
import java.util.Random;
import java.util.Vector;

import core.ParameterGroup;


/**
 * This class defines several method used by other classes.
 */
public class SmallHelpers {
	/**
	 * Converts an array of strings into a vector and returns it.
	 */
	public static Vector<String> arrayToVector(String[] args) {
		Vector<String> result = new Vector<String>();
		for (int curPos = 0; curPos < args.length; curPos++) {
			result.add(args[curPos]);
		}
		return result;
	}


	/**
	 * This method returns the parameter group from the passed vector
	 * which matches the passed name.
	 */
	public static ParameterGroup findParameterGroupByName(String targetName, Vector<ParameterGroup> groups) {
		for (ParameterGroup curParameterGroup : groups) {
			if (curParameterGroup.getName().equals(targetName))
				return curParameterGroup;
		}

		return null;
	}
	
	/**
	 * Checks if a given file exists and can be read by the user.
	 * If a $HOME variable is found, it is replaced before performing
	 * the above mentioned checks. 
	 */
	public static boolean fileReadable(File orgFile) {
		File file = new File(replaceVariables(orgFile.getPath()));
		return file.canRead() && file.exists();
	}
	
	/**
	 * Checks if a given file can be written by the user.
	 * If a $HOME variable is found, it is replaced before performing
	 * the above mentioned checks. 
	 */
	public static boolean fileWriteable(File orgFile) {
		File file = new File(replaceVariables(orgFile.getPath()));
		return file.getParentFile().canWrite();
	}

	/**
	 * Replaces any bash-style variables found in the passed
	 * string with the corresponding values.
	 */
	public static String replaceVariables(String fileName) {
		String result = fileName.replace("${HOME}", System.getProperty("user.home"));	
		return result;
	}


	public static Vector<String> intersect(Vector<String> a, Vector<String> b) {
		if (a == null)
			return b;
		else if (b == null)
			return a;
		else {
			Vector<String> result = new Vector<String>();
			for (String curA : a) {
				boolean found = false;
				for (String curB : b) {
					if (curA.equals(curB)) {
						found = true;
						break;
					}
				}
				if (found)
					result.add(curA);
			}
			
			return result;			
		}
	}

}
