/*
 * 
 * ProFiDo - The Processes Fitting Toolkit Dortmund
 * Copyright (C) 2010 - 2012 LS Informatik IV, TU Dortmund
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

package helper.testmanager;

import gui.MainWindowFrame;
import gui.WorkflowPanel;
import helper.SmallHelpers;

import java.awt.AWTException;
import java.awt.Point;
import java.awt.event.InputEvent;
import java.lang.reflect.Type;
import java.util.Vector;

import javax.swing.JPanel;

import core.graph.BasicNode;

/**
 * This subclass tests the main GUI by performing a series of random 
 * modifications (deleting nodes and edges) to the workflow and undoing 
 * these changes afterwards. The nodes and edges that will be deleted
 * are randomly selected, using the time since midnight, January 1, 1970 
 * UTC as seed for the random number generator.
 */
public class WorkflowPanelTestManager extends TestManager {
	public WorkflowPanelTestManager(MainWindowFrame window, JPanel targetPanel, long seed) throws AWTException {
		super(window, targetPanel, seed);
	}

	@Override
	public void performTests(int testInteractionCount, int testDelay) {
		int jobsToDelete = testInteractionCount / 2;
		int edgesToDelete = testInteractionCount - jobsToDelete;

		// Ensure that the amount of deleted jobs and endges is limited by the 
		// acutal amount of nodes and edges 
		int jobCount = ((WorkflowPanel)targetPanel).getJobNodePositions().size();
		int edgeCount = ((WorkflowPanel)targetPanel).getEdgePositions().size();		
		if (jobsToDelete > jobCount)
			jobsToDelete = jobCount;
		if (edgesToDelete > edgeCount)
			edgesToDelete = edgeCount;

		// Delete jobs
		for (int i = 0;i<jobsToDelete;i++) {
			deleteRandomJob(testDelay);
			delay(testDelay);
		}

		// Restore jobs
		for (int i = 0;i<jobsToDelete;i++) {
			rootWindow.getUndoMenuItem().doClick();
			//delay(testDelay);		
		}

		// Delete edges
		for (int i = 0;i<edgesToDelete;i++) {
			deleteRandomEdge(testDelay);
			delay(testDelay);		
		}

		// Restore edges
		for (int i = 0;i<edgesToDelete;i++) {
			rootWindow.getUndoMenuItem().doClick();
			//delay(testDelay);			
		}
	}

	private void delay(int testDelay) {
		try {
			Thread.sleep(testDelay);
		} catch (InterruptedException e) {
		}
		
	}

	public void deleteRandomJob(int testDelay) {
		Vector<Point> jobPositions = ((WorkflowPanel)targetPanel).getJobNodePositions();
		if (jobPositions.size() > 0) {
			Point targetJobLocation = jobPositions.get(getRandom(jobPositions.size()));
			deleteNodeAtPosition(targetJobLocation.x, targetJobLocation.y, "job", testDelay);			
		}
	}

	public void deleteRandomEdge(int testDelay) {
		Vector<Point> edgePositions = ((WorkflowPanel)targetPanel).getEdgePositions();
		if (edgePositions.size() > 0) {
			Point targetEdgePosition = edgePositions.get(getRandom(edgePositions.size()));
			deleteNodeAtPosition(targetEdgePosition.x, targetEdgePosition.y, "edge", testDelay);			
		}
	}

	private void deleteNodeAtPosition(int curX, int curY, String type, int testDelay) {
		try {
			testRobot.mouseMove(curX + targetPanelUpperLeftInScreenCoordinates.x, curY + targetPanelUpperLeftInScreenCoordinates.y);
			testRobot.mousePress(InputEvent.BUTTON3_MASK);
			testRobot.mouseRelease(InputEvent.BUTTON3_MASK);
			delay(testDelay);
			if (type.equals("job"))
				((WorkflowPanel)targetPanel).getDeleteJobMenuItem().doClick();
			else if (type.equals("edge"))
				((WorkflowPanel)targetPanel).getDeleteEdgeMenuItem().doClick();
			testRobot.mouseMove(curX + targetPanelUpperLeftInScreenCoordinates.x - 10, curY + targetPanelUpperLeftInScreenCoordinates.y - 10);
			testRobot.mousePress(InputEvent.BUTTON1_MASK);
			testRobot.mouseRelease(InputEvent.BUTTON1_MASK);
		} catch (Exception e) {
			e.printStackTrace();
		}


	}


}
